@@ -88,10 +88,10 @@ class AsrClient(AbstractClient):
 
 
     def CreateAsyncRecognitionTask(self, request):
-        """本接口用于对语音流进行准实时识别，通过异步回调来返回识别结果。
+        """本接口用于对语音流进行准实时识别，通过异步回调来返回识别结果。适用于直播审核等场景。
         <br>• 支持rtmp、hls、rtsp等流媒体协议，以及各类基于http协议的直播流
         <br>• 音频流时长无限制，服务会自动拉取音频流数据，若连续10分钟拉不到流数据时，服务会终止识别任务
-        <br>• 服务通过回调的方式来提供识别结果，用户需要提供CallbackUrl
+        <br>• 服务通过回调的方式来提供识别结果，用户需要提供CallbackUrl。回调时机为一小段话(最长15秒)回调一次。
         <br>• 签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
         <br>• 默认单账号限制并发数为20路，如您有提高并发限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
 
@@ -150,7 +150,7 @@ class AsrClient(AbstractClient):
 
     def CreateRecTask(self, request):
         """本接口服务对时长5小时以内的录音文件进行识别，异步返回识别全部结果。
-        <br>• 支持中文普通话、英语、粤语、日语和上海话方言
+        <br>• 支持中文普通话、英语、粤语、日语、泰语
         <br>• 支持通用、音视频领域
         <br>• 支持wav、mp3、m4a、flv、mp4、wma、3gp、amr、aac、ogg-opus、flac格式
         <br>• 支持语音 URL 和本地语音文件两种请求方式
